from Products.Archetypes.public import *

try:
    from Products.ATContentTypes.content.file import ATFile, ATFileSchema
except ImportError:
    # For ATCT 0.2 compatibility
    from Products.ATContentTypes.types.ATFile import ATFile
    from Products.ATContentTypes.types.schemata import ATFileSchema

try :
    from Products.CMFCore import permissions
except ImportError:
    # For CMF 1.4 compatibility
    from Products.CMFCore import CMFCorePermissions
    permissions = CMFCorePermissions

from Products.CMFCore.utils import getToolByName
from AccessControl import ClassSecurityInfo
from config import *


schema = ATFileSchema + Schema((

    TextField('body',
              required = False,
              searchable = True,
              widget=RichWidget(description='Explanatory text',
                                description_msgid ="desc_description",
                                label='Text',
                                label_msgid ='label_description',                                
                                i18n_domain = 'ATGeogebra',
                                rows=25),

             ),


    StringField('width',
                 required = False,
                 searchable = False,
                 default = '100%',
                 widget=StringWidget(label ='Width', modes= ('view','edit',),
                                      label_msgid ='label_width',
                                      description = 'Width of the applet. Pixels or %',
                                      description_msgid ="desc_width",
                                      i18n_domain='ATGeogebra'),
                 ),
    
    StringField('height',
                 required = False,
                 searchable = False,
                 default = '100%',
                 widget=StringWidget(label ='Height', modes= ('view','edit'),
                                      label_msgid ='label_height',
                                      description = 'Height of the applet. Pixels or %',
                                      description_msgid ="desc_height",
                                      i18n_domain='ATGeogebra'),
                 ),

    BooleanField('showAlgebraInput',
                required=False,
                mode="rw",
                default=False,
                widget=BooleanWidget(
                        label="Show Algebra Input",
                        label_msgid="label_showAlgebraInput",
                        description="States whether the algebra input line should be shown in the applet.",
                        description_msgid="desc_showAlgebraInput",
                        i18n_domain = "ATGeogebra"),
                ),


    BooleanField('showMenuBar',
                required=False,
                mode="rw",
                default=False,
                widget=BooleanWidget(
                        label="Show Menu Bar",
                        label_msgid="label_showMenuBar",
                        description="States whether the menubar of GeoGebra should be shown in the applet.",
                        description_msgid="desc_showMenuBar",
                        i18n_domain = "ATGeogebra"),
                ),
 
   BooleanField('showToolBar',
                required=False,
                mode="rw",
                default=False,
                widget=BooleanWidget(
                        label="Show Tool Bar",
                        label_msgid="label_showToolBar",
                        description="States whether the toolbar with the construction mode buttons should be shown in the applet.",
                        description_msgid="desc_showToolBar",
                        i18n_domain = "ATGeogebra"),
                ),

   BooleanField('showToolBarHelp',
                required=False,
                mode="rw",
                default=False,
                widget=BooleanWidget(
                        label="Show Tool Bar Help",
                        label_msgid="label_showToolBarHelp",
                        description="States whether the toolbar help text right to the toolbar buttons should be shown in the applet.",
                        description_msgid="desc_showToolBarHelp",
                        i18n_domain = "ATGeogebra"),
                ),

   BooleanField('framePossible',
                required=False,
                mode="rw",
                default=True,
                widget=BooleanWidget(
                        label="Application frame possible",
                        label_msgid="label_framePossible",
                        description="States if a double click on the drawing pad should open the GeoGebra application frame.",
                        description_msgid="desc_framePossible",
                        i18n_domain = "ATGeogebra"),
                ),

    BooleanField('enableChooserPopups',
                required=False,
                mode="rw",
                default=True,
                widget=BooleanWidget(
                        label="Chooser Popups",
                        label_msgid="label_enableChooserPopups",
                        description="Controls whether a popup menu is shown or not when you click on multiple objects.",
                        description_msgid="desc_enableChooserPopups",
                        i18n_domain = "ATGeogebra"),
                ),

    BooleanField('enableRightClick',
                required=False,
                mode="rw",
                default=True,
                widget=BooleanWidget(
                        label="Enable right click",
                        label_msgid="label_enableRightClick",
                        description="States whether right clicks should be handled by the applet. Enable/disables context menus, properties dialogs and right-click-zooming.",
                        description_msgid="desc_enableRightClick",
                        i18n_domain = "ATGeogebra"),
                ),

    BooleanField('enableLabelDrags',
                required=False,
                mode="rw",
                default=True,
                widget=BooleanWidget(
                        label="Enable Label Drags",
                        label_msgid="label_enableLabelDrags",
                        description="States whether labels can be dragged.",
                        description_msgid="desc_enableLabelDrags",
                        i18n_domain = "ATGeogebra"),
                ),

    BooleanField('allowRescaling',
                required=False,
                mode="rw",
                default=False,
                widget=BooleanWidget(
                        label="Enable Rescaling",
                        label_msgid="label_allowRescaling",
                        description="Determines whether the applet will attempt to rescale the Graphics View when the applet is loaded or the size is changed (eg Zooming in the browser).",
                        description_msgid="desc_allowRescaling",
                        i18n_domain = "ATGeogebra"),
                )


    ))


class ATGeogebra(ATFile):
    """A Geogebra activity file"""
    
    schema = schema
    archetype_name = 'Geogebra Activity File'
    meta_type = 'GeogebraFile'
    portal_type = 'GeogebraFile'
    content_icon = 'geogebra_applet.gif'
    immediate_view = 'geogebrafile_view'
    default_view   = 'geogebrafile_view'
    suppl_views    = ()
    typeDescription= "Geogebra Activity File"
    typeDescMsgId  = 'description_edit_geogebra_file'
    assocFileExt   = ('ggb',)
    
    global_allow = True

    security = ClassSecurityInfo()

    security.declareProtected(permissions.ModifyPortalContent, 'setFile')
    
    def setFile(self, value, **kwargs):
        """Saves file and stores geogebra applet informations (size etc)"""
        ATFile.setFile(self, value, **kwargs)

    security.declarePublic('getIcon')
    def getIcon(self, relative_to_portal=0):
        """Returns icon for Geogebra file"""
        icon = self.content_icon

        if relative_to_portal:
            return icon
        else:
            utool = getToolByName( self, 'portal_url' )
            # Relative to REQUEST['BASEPATH1']
            res = utool(relative=1) + '/' + icon
            while res[:1] == '/':
                res = res[1:]
            return res

registerType(ATGeogebra)
